@@ -164,8 +164,6 @@ su_port_vtable_t const su_select_port_vtable[1] =
       su_base_port_max_defer,
       su_socket_port_wakeup,
       su_base_port_is_running,
-      su_base_port_stamp64,
-      su_base_port_stamp64_offset,
     }};
 
 static char const *su_select_port_name(su_port_t const *self)
@@ -597,9 +595,9 @@ int su_select_port_wait_events(su_port_t *self, su_duration_t tout)
     ser->ser_wait->revents = 0;
 
     if (ser->ser_wait->events & SU_WAIT_IN)
-      if (FD_ISSET(fd, rset)) ser->ser_wait->revents |= SU_WAIT_IN, n--;
+      if (rset && FD_ISSET(fd, rset)) ser->ser_wait->revents |= SU_WAIT_IN, n--;
     if (ser->ser_wait->events & SU_WAIT_OUT)
-      if (FD_ISSET(fd, wset)) ser->ser_wait->revents |= SU_WAIT_OUT, n--;
+      if (wset && FD_ISSET(fd, wset)) ser->ser_wait->revents |= SU_WAIT_OUT, n--;
 
     if (ser->ser_wait->revents) {
       magic = ser->ser_root ? su_root_magic(ser->ser_root) : NULL;
