@@ -102,50 +102,52 @@ static void tport_sctp_timer(tport_t *self, su_time_t);
 
 tport_vtable_t const tport_sctp_client_vtable =
 {
-  "sctp", tport_type_client,
-  sizeof (tport_primary_t),
-  tport_sctp_init_client,
-  NULL,
-  tport_accept,
-  NULL,
-  sizeof (tport_t),
-  tport_sctp_init_secondary,
-  NULL,
-  NULL,
-  NULL,
-  NULL,
-  tport_recv_sctp,
-  tport_send_sctp,
-  NULL,
-  NULL,
-  NULL,
-  NULL,
-  tport_sctp_next_timer,
-  tport_sctp_timer,
+  /* vtp_name 		     */ "sctp",
+  /* vtp_public              */ tport_type_client,
+  /* vtp_pri_size            */ sizeof (tport_primary_t),
+  /* vtp_init_primary        */ tport_sctp_init_client,
+  /* vtp_deinit_primary      */ NULL,
+  /* vtp_wakeup_pri          */ tport_accept,
+  /* vtp_connect             */ NULL,
+  /* vtp_secondary_size      */ sizeof (tport_t),
+  /* vtp_init_secondary      */ tport_sctp_init_secondary,
+  /* vtp_deinit_secondary    */ NULL,
+  /* vtp_shutdown            */ NULL,
+  /* vtp_set_events          */ NULL,
+  /* vtp_wakeup              */ NULL,
+  /* vtp_recv                */ tport_recv_sctp,
+  /* vtp_send                */ tport_send_sctp,
+  /* vtp_deliver             */ NULL,
+  /* vtp_prepare             */ NULL,
+  /* vtp_keepalive           */ NULL,
+  /* vtp_stun_response       */ NULL,
+  /* vtp_next_secondary_timer*/ tport_sctp_next_timer,
+  /* vtp_secondary_timer     */ tport_sctp_timer,
 };
 
 tport_vtable_t const tport_sctp_vtable =
 {
-  "sctp", tport_type_local,
-  sizeof (tport_primary_t),
-  tport_sctp_init_primary,
-  NULL,
-  tport_accept,
-  NULL,
-  sizeof (tport_t),
-  tport_sctp_init_secondary,
-  NULL,
-  NULL,
-  NULL,
-  NULL,
-  tport_recv_sctp,
-  tport_send_sctp,
-  NULL,
-  NULL,
-  NULL,
-  NULL,
-  tport_sctp_next_timer,
-  tport_sctp_timer,
+  /* vtp_name 		     */ "sctp",
+  /* vtp_public              */ tport_type_local,
+  /* vtp_pri_size            */ sizeof (tport_primary_t),
+  /* vtp_init_primary        */ tport_sctp_init_primary,
+  /* vtp_deinit_primary      */ NULL,
+  /* vtp_wakeup_pri          */ tport_accept,
+  /* vtp_connect             */ NULL,
+  /* vtp_secondary_size      */ sizeof (tport_t),
+  /* vtp_init_secondary      */ tport_sctp_init_secondary,
+  /* vtp_deinit_secondary    */ NULL,
+  /* vtp_shutdown            */ NULL,
+  /* vtp_set_events          */ NULL,
+  /* vtp_wakeup              */ NULL,
+  /* vtp_recv                */ tport_recv_sctp,
+  /* vtp_send                */ tport_send_sctp,
+  /* vtp_deliver             */ NULL,
+  /* vtp_prepare             */ NULL,
+  /* vtp_keepalive           */ NULL,
+  /* vtp_stun_response       */ NULL,
+  /* vtp_next_secondary_timer*/ tport_sctp_next_timer,
+  /* vtp_secondary_timer     */ tport_sctp_timer,
 };
 
 static int tport_sctp_init_primary(tport_primary_t *pri,
@@ -258,6 +260,9 @@ int tport_recv_sctp(tport_t *self)
   if (self->tp_master->mr_dump_file)
     tport_dump_iovec(self, msg, N, iovec, veclen, "recv", "from");
 
+ if (self->tp_master->mr_capt_sock)
+     tport_capt_msg(self, msg, N, iovec, veclen, "recv");
+     
   msg_recv_commit(msg, N, 0);  /* Mark buffer as used */
 
   return 2;
@@ -323,4 +328,7 @@ void tport_sctp_timer(tport_t *self, su_time_t now)
   tport_base_timer(self, now);
 }
 
+#else
+/* ISO c99 forbids empty source file */
+void *sofia_tport_type_sctp_dummy;
 #endif
